RestService<Id, Data> class

Queries an Angel service via REST.

Inheritance

Constructors

RestService(BaseClient client, BaseAngelClient app, dynamic url, Type? type)

Properties

app → BaseAngelClient
The Angel instance powering this service.
finalinherited
baseUrl → Uri
finalinherited
client → BaseClient
finalinherited
deserializer → AngelDeserializer<Data>?
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
onCreated → Stream<Data?>
Fired on created events.
no setterinherited
onIndexed → Stream<List<Data?>>
Fired on indexed events.
no setterinherited
onModified → Stream<Data?>
Fired on modified events.
no setterinherited
onRead → Stream<Data?>
Fired on read events.
no setterinherited
onRemoved → Stream<Data?>
Fired on removed events.
no setterinherited
onUpdated → Stream<Data?>
Fired on updated events.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → Type?
final

Methods

close() → Future
inherited
create(Data? data, [Map<String, dynamic>? params]) → Future<Data?>
Creates a resource.
inherited
deserialize(dynamic x) → Data?
override
index([Map<String, dynamic>? params]) → Future<List<Data>>
Retrieves all resources.
inherited
makeBody(dynamic x) → String
override
map<U>(U encoder(Data?), Data? decoder(U)) → Service<Id, U>
Creates a Service that wraps over this one, and maps input and output using two converter functions.
inherited
modify(Id id, Data? data, [Map<String, dynamic>? params]) → Future<Data?>
Modifies a resource.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
read(Id id, [Map<String, dynamic>? params]) → Future<Data?>
Retrieves the desired resource.
inherited
remove(Id id, [Map<String, dynamic>? params]) → Future<Data?>
Removes the given resource.
inherited
send(BaseRequest request) → Future<StreamedResponse>
inherited
toString() → String
A string representation of this object.
inherited
update(Id id, Data? data, [Map<String, dynamic>? params]) → Future<Data?>
Overwrites a resource.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited